package com.jiuqi.grid;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import com.jiuqi.util.Stream;
import com.jiuqi.util.StreamException;
import com.jiuqi.util.inifile.StreamIni;
import java.io.Serializable;
import java.util.Enumeration;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.Set;

public class KeyValues implements Serializable {
  private static final String GRID_KEY_SIGN = "KEYS";
  
  private Hashtable keyMaps = new Hashtable<Object, Object>();
  
  public String getValue(String key) {
    if (this.keyMaps.containsKey(key))
      return (String)this.keyMaps.get(key); 
    return "";
  }
  
  public void setValue(String key, String value) {
    if (this.keyMaps.containsKey(key))
      this.keyMaps.remove(key); 
    if (value != null && value.length() > 0)
      this.keyMaps.put(key, value); 
  }
  
  public boolean getAsBoolean(String key) {
    return "1".equals(getValue(key));
  }
  
  public void setAsBoolean(String key, boolean value) {
    setValue(key, value ? "1" : "0");
  }
  
  public int getAsInt(String key) {
    String value = getValue(key);
    if (value == null || value.length() == 0)
      return 0; 
    return Integer.parseInt(value);
  }
  
  public void setAsInt(String key, int value) {
    setValue(key, Integer.toString(value));
  }
  
  public void clear() {
    this.keyMaps.clear();
  }
  
  private void loadFromStreamIni(Stream stream) throws StreamException {
    this.keyMaps.clear();
    if (stream == null || stream.getSize() == 0L)
      return; 
    StreamIni ini = new StreamIni(stream);
    int c = ini.readInteger("general", "count", 0);
    for (int i = 0; i < c; i++) {
      String key = ini.readString("keys", Integer.toString(i), null);
      String value = ini.readString("values", Integer.toString(i), null);
      if (key != null && key.length() > 0 && value != null && value.length() > 0)
        this.keyMaps.put(key, value); 
    } 
  }
  
  public void saveToStreamIni(Stream stream) throws StreamException {
    stream.setSize(0L);
    StreamIni ini = new StreamIni(stream);
    int c = 0;
    Enumeration<String> keys = this.keyMaps.keys();
    while (keys.hasMoreElements()) {
      String key = keys.nextElement();
      String value = (String)this.keyMaps.get(key);
      ini.writeString("keys", Integer.toString(c), key);
      ini.writeString("values", Integer.toString(c), value);
      c++;
    } 
    ini.writeInteger("general", "count", c);
    ini.update();
  }
  
  public void loadFromStream(Stream stream) throws StreamException {
    this.keyMaps.clear();
    if (stream.getSize() < 8L)
      return; 
    stream.seek(-4L, 2);
    String sign = stream.readString(4);
    if ("BINI".equals(sign)) {
      loadFromStreamIni(stream);
    } else if ("KEYS".equals(sign)) {
      stream.seek(0L, 0);
      int c = stream.readInt();
      for (int i = 0; i < c; i++) {
        String key = stream.readStringBySize();
        String value = stream.readStringBySize();
        if (key != null && value != null)
          this.keyMaps.put(key, value); 
      } 
    } 
  }
  
  public void saveToStream(Stream stream) throws StreamException {
    Set keys = this.keyMaps.keySet();
    stream.writeInt(keys.size());
    Iterator<String> keyItr = keys.iterator();
    while (keyItr.hasNext()) {
      String key = keyItr.next();
      stream.writeStringWithSize(key);
      String value = (String)this.keyMaps.get(key);
      stream.writeStringWithSize(value);
    } 
    stream.writeString("KEYS");
  }
}
